/*complex alarm code includes entry and exit delays, status report to serial monitor, Status leds and control button.
  Pin configuration works on ThinkerShield
  Each press changes mode
  set threshold ONLY in standby mode.
  LED 13 lights when threshold (Pot) value is 50 plus half the LDR value. 
  adjust pot so SetLED is just on in the light.
  SetLED should be off when in dark.
 */
int potPin = 5;       //potPin is connected to a potentiometer and adjusts the threshold for alarm trigger
int potValue = 0;     
int LDRPin = 4;       //LDR Pin is connected to an LDR to detect openning drawer
int LDRValue = 0;
int Status = 0;       //Status of alarm 0=standby, 1=exit delay, 2=armed, 3=exit delay, 4=triggered
int buzzerPin = 3;    //connect to buzzer
int buttonPin = 7;    //connected to button and controls alarm status
int buttonValue = 0;

int standbyLEDPin = 8; //indicator LEDs
int exitLEDPin = 9;
int armedLEDPin = 10;
int entryLEDPin = 11;
int triggeredLEDPin = 12;
int SetLEDPin = 13;   //indicates if potValue is <LDRValue in standby mode.


void setup() {
  // Setup inputs, outputs and serial monitor
pinMode(potPin,INPUT);
pinMode(LDRPin,INPUT);
pinMode(buttonPin,INPUT);
pinMode(buzzerPin,OUTPUT);

pinMode (standbyLEDPin,OUTPUT);
pinMode (exitLEDPin,OUTPUT);
pinMode (armedLEDPin,OUTPUT);
pinMode (entryLEDPin,OUTPUT);
pinMode (triggeredLEDPin,OUTPUT);
pinMode (SetLEDPin,OUTPUT);

Serial.begin(9600);
}

void loop() {
  
if(Status ==0){                      //Run this section if in standby mode
 digitalWrite(exitLEDPin,LOW);       //other LEDs off
 digitalWrite(armedLEDPin,LOW);
 digitalWrite(entryLEDPin,LOW);
 digitalWrite(triggeredLEDPin,LOW);

  digitalWrite(standbyLEDPin,HIGH);  //standby LED on
   potValue = analogRead(potPin);    //read values of pot and LDR
   LDRValue = analogRead(LDRPin);
    Serial.print("STANDBY   ");      //Print values and status to serial monitor 
    Serial.print("Threshold level: ");
    Serial.print(potValue);
    Serial.print("    Light level: ");
    Serial.println(LDRValue);
  if(potValue<(50+(LDRValue/2))){            //Turn on LED13 if potvalue is half LDR value plus 50.
     digitalWrite(SetLEDPin,HIGH);
  }else{
     digitalWrite(SetLEDPin,LOW);}
     
    buttonValue = digitalRead(buttonPin); //Check if button is pressed to move status into exit delay mode.
    if(buttonValue == 1){
      Status = 1;
      delay(400);}
}
if(Status==1){                      //Run this section if in exit mode
 digitalWrite(standbyLEDPin,LOW);   //other LEDs off
 digitalWrite(armedLEDPin,LOW);
 digitalWrite(entryLEDPin,LOW);
 digitalWrite(triggeredLEDPin,LOW);
 digitalWrite(SetLEDPin,LOW);

  digitalWrite(exitLEDPin,HIGH);   //exit LED on
  Serial.println ("EXIT DELAY");   //print EXIT DELAY to serial monitor
  delay(3000);                     //wait 3 seconds then chirp twice
  tone(buzzerPin,600,20);
  delay(200);
  tone(buzzerPin,600,20);
  Status = 2;}                    //change status to armed

if(Status == 2){                  //Run this section if in armed mode
 digitalWrite(standbyLEDPin,LOW); //other LEDs off
 digitalWrite(exitLEDPin,LOW);
 digitalWrite(entryLEDPin,LOW);
 digitalWrite(triggeredLEDPin,LOW);
 digitalWrite(SetLEDPin,LOW);

  digitalWrite(armedLEDPin,HIGH);  //armed LED on
  Serial.print ("ARMED  ");        //print ARMED to serial monitor
  LDRValue = analogRead(LDRPin);   //Read LDR value and test if triggered
  Serial.print("Threshold level: ");
  Serial.print(potValue);
  Serial.print("    Light level: ");
  Serial.println(LDRValue);
   if(potValue<LDRValue){
    Status = 3;                    //change status to exit mode
    }}

    
if(Status == 3){                   //Run this section if in entry mode
 digitalWrite(standbyLEDPin,LOW);  //other LEDs off
 digitalWrite(exitLEDPin,LOW);
 digitalWrite(armedLEDPin,LOW);
 digitalWrite(triggeredLEDPin,LOW);
 digitalWrite(SetLEDPin,LOW);

  digitalWrite(entryLEDPin,HIGH);        //entry LED on
  Serial.println ("ENTRY DELAY");        //print ENTRY DELAY to serial monitor
  for(int count=0;count<=300;count++){   //this loops 300 times to test for reset button press 
    buttonValue = digitalRead(buttonPin); 
    if(buttonValue == 1){
      delay(200);
      Status = 0;
      count = 299;
    }else{
      delay(10);
    }}}
if(Status==3){                          //sets status to triggered mode 
    Status = 4;
    }
if (Status==4){                        //Run this section if in triggered mode
 digitalWrite(standbyLEDPin,LOW);      //other LEDs off
 digitalWrite(exitLEDPin,LOW);
 digitalWrite(armedLEDPin,LOW);
 digitalWrite(entryLEDPin,LOW);
 digitalWrite(SetLEDPin,LOW);
 
  digitalWrite(triggeredLEDPin,HIGH); //triggered LED on
  Serial.println ("TRIGGERED");       //print TRIGGERED to serial monitor
  tone(buzzerPin,600,50);             //play alarm tone 
    buttonValue = digitalRead(buttonPin); 
    if(buttonValue == 1){             //test for reset button. If pressed set atatus to standby
      delay(200);
      Status = 0;
    }}}
